@@ -34,7 +34,10 @@ def getCap(b, path):
 		b.find('div', class_='topic-richtext') or
 		b.find('p', id='first', class_='lead'))
 	if 'douban' in path and 'group/topic' in path:
-		title = b.find('title').text.strip()
+		try:
+			title = b.find('td', class_='tablecc').text[3:]
+		except:
+			title = b.find('title').text.strip()
 		content = b.find('div', class_='topic-richtext')
 		for item in content.find_all('p'):
 			item.append('\n\n')
